lib.docker.common


*host*clj

source

*timeout*clj

source

get-ipclj

(get-ip container-id)

gets the ip of a container

gets the ip of a container
sourceraw docstring

get-published-portclj

(get-published-port container-id port)

gets the host port published for a container port

(get-published-port cid 8080) => 56108

gets the host port published for a container port

(get-published-port cid 8080)
=> 56108
sourceraw docstring

has-container?clj

(has-container? {:keys [id group] :or {group "testing"}})

checks that a container exists

checks that a container exists
sourceraw docstring

list-containersclj

(list-containers)
(list-containers opts tail)

gets all local containers

(list-containers) => vector?

gets all local containers

(list-containers)
=> vector?
sourceraw docstring

raw-commandclj

(raw-command command & [opts tail])

executes a docker command

executes a docker command
sourceraw docstring

raw-execclj

(raw-exec args opts)

executes a shell command

executes a shell command
sourceraw docstring

start-containerclj

(start-container {:keys [group id image cmd flags labels volumes environment
                         ports expose remove detached no-host]
                  :as m
                  :or {remove true detached true group "testing"}}
                 &
                 [repeat])

starts a container

starts a container
sourceraw docstring

stop-containerclj

(stop-container {:keys [group id] :as m :or {group "testing"}})

stops a container

stops a container
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries