(get-ip container-id)gets the ip of a container
gets the ip of a container
(get-published-port container-id port)gets the host port published for a container port
(get-published-port cid 8080) => 56108
gets the host port published for a container port (get-published-port cid 8080) => 56108
(has-container? {:keys [id group] :or {group "testing"}})checks that a container exists
checks that a container exists
(list-containers)(list-containers opts tail)gets all local containers
(list-containers) => vector?
gets all local containers (list-containers) => vector?
(raw-command command & [opts tail])executes a docker command
executes a docker command
(raw-exec args opts)executes a shell command
executes a shell command
(start-container {:keys [group id image cmd flags labels volumes environment
ports expose remove detached no-host]
:as m
:or {remove true detached true group "testing"}}
&
[repeat])starts a container
starts a container
(stop-container {:keys [group id] :as m :or {group "testing"}})stops a container
stops a container
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |